==> zio-aws-cloudformation_2.12-5.17.102.7-sources.jar: zio/aws/cloudformation/model/ListStackSetOperationResultsRequest.scala <==
package zio.aws.cloudformation.model
import java.lang.Integer
import zio.aws.cloudformation.model.primitives.{
  MaxResults,
  NextToken,
  ClientRequestToken,
  StackSetName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListStackSetOperationResultsRequest(
    stackSetName: StackSetName,
    operationId: ClientRequestToken,
    nextToken: Option[NextToken] = None,
    maxResults: Option[MaxResults] = None,
    callAs: Option[zio.aws.cloudformation.model.CallAs] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest = {
    import ListStackSetOperationResultsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest
      .builder()
      .stackSetName(StackSetName.unwrap(stackSetName): java.lang.String)
      .operationId(ClientRequestToken.unwrap(operationId): java.lang.String)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(callAs.map(value => value.unwrap))(_.callAs)
      .build()
  }
  def asReadOnly
      : zio.aws.cloudformation.model.ListStackSetOperationResultsRequest.ReadOnly =
    zio.aws.cloudformation.model.ListStackSetOperationResultsRequest
      .wrap(buildAwsValue())
}
object ListStackSetOperationResultsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cloudformation.model.ListStackSetOperationResultsRequest =
      zio.aws.cloudformation.model.ListStackSetOperationResultsRequest(
        stackSetName,
        operationId,
        nextToken.map(value => value),
        maxResults.map(value => value),
        callAs.map(value => value)
      )
    def stackSetName: StackSetName
    def operationId: ClientRequestToken
    def nextToken: Option[NextToken]
    def maxResults: Option[MaxResults]
    def callAs: Option[zio.aws.cloudformation.model.CallAs]
    def getStackSetName: ZIO[Any, Nothing, StackSetName] =
      ZIO.succeed(stackSetName)
    def getOperationId: ZIO[Any, Nothing, ClientRequestToken] =
      ZIO.succeed(operationId)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getCallAs: ZIO[Any, AwsError, zio.aws.cloudformation.model.CallAs] =
      AwsError.unwrapOptionField("callAs", callAs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest
  ) extends zio.aws.cloudformation.model.ListStackSetOperationResultsRequest.ReadOnly {
    override val stackSetName: StackSetName =
      zio.aws.cloudformation.model.primitives.StackSetName(impl.stackSetName())
    override val operationId: ClientRequestToken =
      zio.aws.cloudformation.model.primitives
        .ClientRequestToken(impl.operationId())
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.cloudformation.model.primitives.NextToken(value))
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.cloudformation.model.primitives.MaxResults(value))
    override val callAs: Option[zio.aws.cloudformation.model.CallAs] = scala
      .Option(impl.callAs())
      .map(value => zio.aws.cloudformation.model.CallAs.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest
  ): zio.aws.cloudformation.model.ListStackSetOperationResultsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cloudformation_2.12-5.17.162.1-sources.jar: zio/aws/cloudformation/model/ListStackSetOperationResultsRequest.scala <==
package zio.aws.cloudformation.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.cloudformation.model.primitives.{
  MaxResults,
  NextToken,
  ClientRequestToken,
  StackSetName
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListStackSetOperationResultsRequest(
    stackSetName: StackSetName,
    operationId: ClientRequestToken,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    callAs: Optional[zio.aws.cloudformation.model.CallAs] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest = {
    import ListStackSetOperationResultsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest
      .builder()
      .stackSetName(StackSetName.unwrap(stackSetName): java.lang.String)
      .operationId(ClientRequestToken.unwrap(operationId): java.lang.String)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(callAs.map(value => value.unwrap))(_.callAs)
      .build()
  }
  def asReadOnly
      : zio.aws.cloudformation.model.ListStackSetOperationResultsRequest.ReadOnly =
    zio.aws.cloudformation.model.ListStackSetOperationResultsRequest
      .wrap(buildAwsValue())
}
object ListStackSetOperationResultsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cloudformation.model.ListStackSetOperationResultsRequest =
      zio.aws.cloudformation.model.ListStackSetOperationResultsRequest(
        stackSetName,
        operationId,
        nextToken.map(value => value),
        maxResults.map(value => value),
        callAs.map(value => value)
      )
    def stackSetName: StackSetName
    def operationId: ClientRequestToken
    def nextToken: Optional[NextToken]
    def maxResults: Optional[MaxResults]
    def callAs: Optional[zio.aws.cloudformation.model.CallAs]
    def getStackSetName: ZIO[Any, Nothing, StackSetName] =
      ZIO.succeed(stackSetName)
    def getOperationId: ZIO[Any, Nothing, ClientRequestToken] =
      ZIO.succeed(operationId)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getCallAs: ZIO[Any, AwsError, zio.aws.cloudformation.model.CallAs] =
      AwsError.unwrapOptionField("callAs", callAs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest
  ) extends zio.aws.cloudformation.model.ListStackSetOperationResultsRequest.ReadOnly {
    override val stackSetName: StackSetName =
      zio.aws.cloudformation.model.primitives.StackSetName(impl.stackSetName())
    override val operationId: ClientRequestToken =
      zio.aws.cloudformation.model.primitives
        .ClientRequestToken(impl.operationId())
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.cloudformation.model.primitives.NextToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.cloudformation.model.primitives.MaxResults(value))
    override val callAs: Optional[zio.aws.cloudformation.model.CallAs] =
      zio.aws.core.internal
        .optionalFromNullable(impl.callAs())
        .map(value => zio.aws.cloudformation.model.CallAs.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest
  ): zio.aws.cloudformation.model.ListStackSetOperationResultsRequest.ReadOnly =
    new Wrapper(impl)
}
